coherence.backends (package) — Cohen3 0.8.0 documentation

# coherence.backends (package)

The backends package contains a sub package coherence.backends.models which contains some base classes meant to be used to create a custom Backend.

Also contains all Cohen3 available backends. Most of them are BackendStores which allow to create a Media Server for specific situations. Check out each module for further documentation.

Here are all available Cohen3 Backends:

- coherence.backends.ampache_storage (module)
- coherence.backends.appletrailers_storage (module)
  - AppleTrailersStore
- coherence.backends.audiocd_storage (module)
- coherence.backends.axiscam_storage (module)
- coherence.backends.banshee_storage (module)
- coherence.backends.bbc_storage (module)
- coherence.backends.buzztard_control (module)
- coherence.backends.dvbd_storage (module)
- coherence.backends.elisa_renderer (module)
- coherence.backends.elisa_storage (module)
- coherence.backends.feed_storage (module)
- coherence.backends.flickr_storage (module)
- coherence.backends.fs_storage (module)
  - FSStore - filesystem media server
- coherence.backends.gallery2_storage (module)
- coherence.backends.gstreamer_renderer (module)
- coherence.backends.iradio_storage (module)
- coherence.backends.itv_storage (module)
- coherence.backends.lastfm_storage (module)
- coherence.backends.lolcats_storage (module)
  - LolcatsStore
- coherence.backends.mediadb_storage (module)
- coherence.backends.miroguide_storage (module)
- coherence.backends.picasa_storage (module)
- coherence.backends.playlist_storage (module)
- coherence.backends.radiotime_storage (module)
- coherence.backends.swr3_storage (module)
- coherence.backends.ted_storage (module)
  - TEDStore
- coherence.backends.test_storage (module)
- coherence.backends.tracker_storage (module)
- coherence.backends.twitch_storage (module)
- coherence.backends.yamj_storage (module)
- coherence.backends.youtube_storage (module)

## coherence.backends.models (package)

If you plan to write a custom backend this classes should make easier to develop it:

- coherence.backends.models.items (module)
  - Backend models for BackendItem
- coherence.backends.models.containers (module)
  - Backend models for Container
- coherence.backends.models.stores (module)
  - Backend models for BackendStore

If you want to see some more examples about how to apply those classes you can check those backends:

> - AppleTrailersStorage
> - LolcatsStore
> - TedStorage